%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

Name:           ocaml-camlidl
Version:        1.12
Release:        %mkrel 1
Summary:        Stub code generator and COM binding for Objective Caml
Group:          Development/OCaml
License:        QPL and LGPLv2 with exceptions

%global shortversion %(tr -d . <<< %{version})
%global giturl  https://github.com/xavierleroy/camlidl

URL:            https://xavierleroy.org/camlidl/
VCS:            git:%{giturl}.git
Source0:        %{giturl}/archive/camlidl%{shortversion}.tar.gz
# META file from opam (RHBZ#1026991).
Source1:        https://raw.githubusercontent.com/ocaml/opam-repository/master/packages/camlidl/camlidl.%{version}/files/META

# This is the latest prebuilt documentation available.
# Actually building the documentation requires many TeX tools.
Source2:        https://caml.inria.fr/pub/old_caml_site/distrib/bazar-ocaml/camlidl-1.05.doc.pdf

# Both patches sent upstream on 2020-05-20.
# Allow destdir installs.
Patch1:         0001-Allow-destdir-installs.patch
# Pass -g option to ocamlmklib.
Patch2:         0002-Pass-g-option-to-ocamlmklib.patch
# Avoid segfaults in OCaml GC
# https://github.com/xavierleroy/camlidl/commit/346de7b484a087a035af7d14a76d6c1693915e08
# https://github.com/xavierleroy/camlidl/commit/64a30a2385b30cbaf159e0709895ed3efc7ece3f
Patch3:         %{name}-gc-segfault.patch

BuildRequires:  make
BuildRequires:  ocaml
BuildRequires:  ocaml-ocamldoc
BuildRequires:  ocaml-rpm-macros
BuildRequires:  perl

%description
CamlIDL is a stub code generator and COM binding for Objective Caml.

CamlIDL comprises two parts:

* A stub code generator that generates the C stub code required for
  the Caml/C interface, based on an MIDL specification. (MIDL stands
  for Microsoft's Interface Description Language; it looks like C
  header files with some extra annotations, plus a notion of object
  interfaces that look like C++ classes without inheritance.)

* A (currently small) library of functions and tools to import COM
  components in Caml applications, and export Caml code as COM
  components.


%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%prep
%autosetup -n camlidl-camlidl%{shortversion} -p1

sed -e 's|^OCAMLLIB=.*|OCAMLLIB=%{_libdir}/ocaml|' \
    -e 's|^BINDIR=.*|BINDIR=%{_bindir}|' \
    -e 's|^CFLAGS=.*|CFLAGS=%{build_cflags}|' \
%ifarch %{ocaml_native_compiler}
    -e 's|^OCAMLC=.*|OCAMLC=ocamlc.opt -g|' \
    -e 's|^OCAMLOPT=.*|OCAMLOPT=ocamlopt.opt -g|' \
%endif
    < config/Makefile.unix \
    > config/Makefile

# Remove files we do not want to package with the tests
find . \( -name .cvsignore -o -name .gitignore \) -delete

# Preserve timestamps
sed -i 's/cp/cp -p/' runtime/Makefile.unix

cp %{SOURCE2} .


%build
# Parallel builds will fail.
make


%install
mkdir -p %{buildroot}%{_libdir}/ocaml
mkdir -p %{buildroot}%{_libdir}/ocaml/caml
mkdir -p %{buildroot}%{_libdir}/ocaml/stublibs
mkdir -p %{buildroot}%{_bindir}

# Install META file (RHBZ#1026991).  The META file is missing a directory
# directive, which makes ocamlfind complain when building consumers.
sed '/version/adirectory = "^"' %{SOURCE1} > \
    $RPM_BUILD_ROOT/%{ocamldir}/META.camlidl

%make_install
%ocaml_files


%files -f .ofiles
%license LICENSE


%files devel -f .ofiles-devel
%doc README Changes docs tests
%license LICENSE


%changelog
* Sat Jun 21 2025 daviddavid <daviddavid> 1.12-1.mga10
+ Revision: 2193360
- new version: 1.12

* Wed May 18 2022 pterjan <pterjan> 1.09-4.mga9
+ Revision: 1858755
- Rebuild for OCaml 4.14

* Tue Mar 29 2022 umeabot <umeabot> 1.09-3.mga9
+ Revision: 1832123
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 1.09-2.mga9
+ Revision: 1750748
- Rebuild for ocaml 4.13.1

* Wed Mar 03 2021 tv <tv> 1.09-1.mga9
+ Revision: 1696602
- 1.09

* Fri Aug 21 2020 umeabot <umeabot> 1.05-25.mga8
+ Revision: 1617565
- Rebuild for new ocaml deps generator

* Fri Feb 28 2020 umeabot <umeabot> 1.05-24.mga8
+ Revision: 1551134
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.05-23.mga8
+ Revision: 1543452
- Mageia 8 Mass Rebuild

* Tue Oct 23 2018 tv <tv> 1.05-22.mga8
+ Revision: 1324033
- rebuild with ocaml-4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 1.05-21.mga7
+ Revision: 1323727
- Rebuild for ocaml 4.07

* Sun Sep 23 2018 umeabot <umeabot> 1.05-20.mga7
+ Revision: 1299846
- Mageia 7 Mass Rebuild

* Sun Nov 26 2017 tv <tv> 1.05-19.mga7
+ Revision: 1179364
- fix build
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 1.05-18.mga6
+ Revision: 1056267
- Rebuild for fix in ocaml

* Fri Feb 12 2016 umeabot <umeabot> 1.05-17.mga6
+ Revision: 956312
- Mageia 6 Mass Rebuild

* Wed Oct 21 2015 tv <tv> 1.05-16.mga6
+ Revision: 893248
- rebuild with fixed deps

* Wed Oct 15 2014 umeabot <umeabot> 1.05-15.mga5
+ Revision: 739659
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.05-14.mga5
+ Revision: 725144
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.05-13.mga5
+ Revision: 683001
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.05-12.mga4
+ Revision: 508431
- Mageia 4 Mass Rebuild
+ blue_prawn <blue_prawn>
- s/Objective Caml/OCaml/ it was decided by the community to only use the name OCaml now

* Sat Jan 12 2013 umeabot <umeabot> 1.05-11.mga3
+ Revision: 361203
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 1.05-10.mga3
+ Revision: 301414
- build requires ocaml-compiler
- rebuild for ocaml-4.00.0
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.05-8.mga3
+ Revision: 300048
- new rpm group for ocaml

* Mon Nov 21 2011 malo <malo> 1.05-7.mga2
+ Revision: 170183
- adding META from Godi
- spec clean-up

* Sat Apr 30 2011 pterjan <pterjan> 1.05-6.mga1
+ Revision: 93950
- Bump release higher than Mandriva

* Mon Mar 07 2011 saispo <saispo> 1.05-1.mga1
+ Revision: 66153
- imported package ocaml-camlidl

